@@ -20,7 +20,10 @@ def upload_note(root, note: EvernoteNote, note_blocks):
     logger.info(f"Creating new page for note '{note.title}'")
     new_page = _make_page(note, root)
 
-    for block in Bar(f"Uploading '{note.title}'").iter(note_blocks):
+    # Escape % to prevent progress bar crashing
+    note_title = note.title.replace("%", "%%")
+
+    for block in Bar(f"Uploading '{note_title}'").iter(note_blocks):
         upload_block(new_page, block)
 
     # Set proper name after everything is uploaded
